"""Generate a strong password which includes alphabets, numbers, special characters"""

__version__ = '1.3.4'

from .__main__ import get_argument, generate_password, main
from .genpasswd import PasswordGenerator



EMPTY_STRING = ""
DEFAULT_SEPARATOR = "-"
DEFAULT_SEPARATE_LENGTH = 4
PASSWORD_LENGTH_LIMIT = 72
DEFAULT_MIN_PASS_LEN = 8
DEFAULT_MAX_PASS_LEN = 16
NO_SHORT = "n"
YES_SHORT = "y"
POSSIBLE_UPPERCASE_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
POSSIBLE_LOWERCASE_CHARS = POSSIBLE_UPPERCASE_CHARS.lower()
POSSIBLE_NUMBERS = "0123456789"
POSSIBLE_SPECIAL_CHARS = '''!"%&'()*,+-./:;<=>?@[]^_`{|}~”$‘~#\\'''
